@@ -12,15 +12,10 @@ class OpenProject:
         OpenProject.input_file()
         OpenProject.confirm()
         OpenProject.close_dialog()
-        sleep(2)
+        sleep(1)
 
     # 2a
     @staticmethod
-    def open_data():
-        Ui_tools.click_on('\static\\2a.png')
-
-    # 2b
-    @staticmethod
     def open_file():
         Ui_tools.hot_key('ctrl', 'shift', 'o')
 
